Package: weatherStats
Title: Airport Weather Station Statistics
Version: 0.1
Authors@R: person("Peter","Hoff",email="peter.hoff@duke.edu",role=c("aut","cre"))
Description: Download daily weather data recorded at airport weather stations using the National Centers for Environmental Information (NCEI) API <https://www.ncei.noaa.gov/support/access-search-service-api-user-documentation>. 
Depends: R (>= 3.5.0)
License: GPL (>= 3)
RoxygenNote: 7.3.3
LazyData: true
NeedsCompilation: no
Packaged: 2026-04-23 12:50:54 UTC; pdh10
Author: Peter Hoff [aut, cre]
Maintainer: Peter Hoff <peter.hoff@duke.edu>
Repository: CRAN
Date/Publication: 2026-04-28 18:10:09 UTC
Built: R 4.5.2; ; 2026-05-01 17:20:59 UTC; unix
