# Generated by roxygen2: do not edit by hand

export(c2f)
export(f2c)
export(isMonth)
export(tpdata)
export(tpplot)
export(weatherStats)
importFrom(grDevices,rgb)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(graphics,segments)
importFrom(graphics,text)
importFrom(utils,read.csv)
