#' @title C to F temperature conversion   
#' 
#' @description Celsius to Fahrenheit temperature coversion  
#' 
#' @param x temperature in Celsius 
#'
#' @return temperature in Fahrenheit
#'
#' @author Peter Hoff  
#'
#' @export
c2f<-function(x){ 32 + 1.8 * x }  

#' @title F to C temperature conversion   
#' 
#' @description Fahrenheit to Celsius temperature coversion  
#' 
#' @param y temperature in Fahrenheit
#' 
#' @return temperature in Celsius 
#'
#' @author Peter Hoff   
#' 
#' @export
f2c <- function(y) { (y - 32) / 1.8 } 


