#' @title Month-specific date extraction 
#' 
#' @description Extract indices of a particular month from ISO 8601 format
#' 
#' @param dates a vector of character dates in IS( 8601 format
#' @param month an integer from 1 to 12
#' 
#' @return a vector of matching indices
#'
#' @author Peter Hoff   
#' 
#' @export
isMonth<-function(dates,month){  
  as.numeric(substring(dates,6,7)) == month
}




