#' RDU weather dataset 
#'
#' Two years of weather data at RDU. 
#'
#' @format A data frame with dates along the rows, variables along the columns.  
#' 
#' @source Derived from original data at https://example.org
"RDU" 

#' SEA weather dataset 
#'
#' One year of weather data at SEA. 
#'
#' @format A data frame with dates along the rows, variables along the columns.  
#' 
#' @source Downloaded via the NCEI API <https://www.ncei.noaa.gov/support/access-search-service-api-user-documentation>. 
"SEA"
