#' Airport Weather Station Statistics
#' 
#' Download daily weather data recorded at airport weather stations using 
#' the National Centers for Environmental Information (NCEI) API 
#' <https://www.ncei.noaa.gov/support/access-search-service-api-user-documentation>. 
#' 
#' 
#' @name weatherStats-package 
#' 
#' @author Peter Hoff <peter.hoff@@duke.edu> 
#' 
#' @keywords internal
#' 
#' @examples 
#' \donttest{
#' RDU<-weatherStats("RDU",startDate="2024-01-01",endDate="2025-12-31") 
#' SEA<-weatherStats("SEA",year=2025)   
#' }
#' W<-tpdata(RDU,SEA) 
#'  
#' colnames(W) 
#' dim(W) 
#' tpplot(W) 
#'
#' @importFrom grDevices rgb
#' @importFrom graphics abline axis par points segments text 
#' @importFrom utils read.csv 
"_PACKAGE" 



