% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/weatherStats.r
\name{weatherStats}
\alias{weatherStats}
\title{Weather Station Statistics}
\usage{
weatherStats(
  FAAID,
  year = NULL,
  startDate = NULL,
  endDate = NULL,
  trimNA = TRUE,
  maxTries = 5,
  tpause = 3,
  verbose = TRUE
)
}
\arguments{
\item{FAAID}{Federal Aviation Administration (FAA) station ID}

\item{year}{year for which data are to be downloaded}

\item{startDate}{start date in YY-MM-DD format}

\item{endDate}{end date in YY-MM-DD format}

\item{trimNA}{remove days with no data}

\item{maxTries}{maximum number of query attempts to the NCEI server}

\item{tpause}{time in seconds to pause between API requests}

\item{verbose}{a logical value indicating whether to report download progress}
}
\value{
a data frame with daily weather data
}
\description{
Download weather data from the National Centers for Environmental Information (NCEI) using their API.
}
\examples{
  
\donttest{
RDU<-weatherStats("RDU",startDate="2024-01-01",endDate="2025-12-31") 
SEA<-weatherStats("SEA",year=2025)   
}
 
dim(RDU) 
dim(SEA) 
colnames(SEA)
 
}
\author{
Peter Hoff
}
