% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tconvert.r
\name{c2f}
\alias{c2f}
\title{C to F temperature conversion}
\usage{
c2f(x)
}
\arguments{
\item{x}{temperature in Celsius}
}
\value{
temperature in Fahrenheit
}
\description{
Celsius to Fahrenheit temperature coversion
}
\author{
Peter Hoff
}
