% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.r
\docType{data}
\name{SEA}
\alias{SEA}
\title{SEA weather dataset}
\format{
A data frame with dates along the rows, variables along the columns.
}
\source{
Downloaded via the NCEI API <https://www.ncei.noaa.gov/support/access-search-service-api-user-documentation>.
}
\usage{
SEA
}
\description{
One year of weather data at SEA.
}
\keyword{datasets}
