% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/weatherStats-package.r
\docType{package}
\name{weatherStats-package}
\alias{weatherStats-package}
\title{Airport Weather Station Statistics}
\description{
Download daily weather data recorded at airport weather stations using 
the National Centers for Environmental Information (NCEI) API 
<https://www.ncei.noaa.gov/support/access-search-service-api-user-documentation>.
}
\examples{
\donttest{
RDU<-weatherStats("RDU",startDate="2024-01-01",endDate="2025-12-31") 
SEA<-weatherStats("SEA",year=2025)   
}
W<-tpdata(RDU,SEA) 
 
colnames(W) 
dim(W) 
tpplot(W) 

}
\author{
Peter Hoff <peter.hoff@duke.edu>
}
\keyword{internal}
