% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/isMonth.r
\name{isMonth}
\alias{isMonth}
\title{Month-specific date extraction}
\usage{
isMonth(dates, month)
}
\arguments{
\item{dates}{a vector of character dates in IS( 8601 format}

\item{month}{an integer from 1 to 12}
}
\value{
a vector of matching indices
}
\description{
Extract indices of a particular month from ISO 8601 format
}
\author{
Peter Hoff
}
