% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tconvert.r
\name{f2c}
\alias{f2c}
\title{F to C temperature conversion}
\usage{
f2c(y)
}
\arguments{
\item{y}{temperature in Fahrenheit}
}
\value{
temperature in Celsius
}
\description{
Fahrenheit to Celsius temperature coversion
}
\author{
Peter Hoff
}
