% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.r
\docType{data}
\name{RDU}
\alias{RDU}
\title{RDU weather dataset}
\format{
A data frame with dates along the rows, variables along the columns.
}
\source{
Derived from original data at https://example.org
}
\usage{
RDU
}
\description{
Two years of weather data at RDU.
}
\keyword{datasets}
