% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tpdata.r
\name{tpdata}
\alias{tpdata}
\title{Temperature and precipitation data}
\usage{
tpdata(...)
}
\arguments{
\item{\ldots}{either a list or sequence of data matrices obtained from `weatherStats`}
}
\value{
a data frame
}
\description{
Extract and combine temperature and precipitation data
}
\examples{
W<-tpdata(RDU,SEA) 
 
colnames(W) 
dim(W) 

tpplot(W) 

}
\author{
Peter Hoff
}
