% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tpplot.r
\name{tpplot}
\alias{tpplot}
\title{Temperature and precipitation plot}
\usage{
tpplot(TPDATA, units = "F", rc = "col")
}
\arguments{
\item{TPDATA}{A data frame with temperature and precipitation data}

\item{units}{"F" or "C"}

\item{rc}{make multiple plots along columns ("col") or rows ("row")}
}
\value{
Invisibly returns \code{NULL}.
}
\description{
Plot temperature and precipitation data
}
\examples{
W<-tpdata(RDU,SEA) 
 
colnames(W) 
dim(W) 

tpplot(W) 

}
\author{
Peter Hoff
}
